@@ -171,6 +171,11 @@ struct _ioa_engine
 
 #define SOCKET_MAGIC (0xABACADEF)
 
+struct traffic_bytes {
+	band_limit_t jiffie_bytes_read;
+	band_limit_t jiffie_bytes_write;
+};
+
 struct _ioa_socket
 {
 	evutil_socket_t fd;
@@ -207,8 +212,8 @@ struct _ioa_socket
 	int current_tos;
 	stun_buffer_list bufs;
 	turn_time_t jiffie; /* bandwidth check interval */
-	band_limit_t jiffie_bytes_read;
-	band_limit_t jiffie_bytes_write;
+	struct traffic_bytes data_traffic;
+	struct traffic_bytes control_traffic;
 	/* RFC 6062 ==>> */
 	//Connection session:
 	tcp_connection *sub_session;
@@ -294,7 +299,7 @@ int ssl_read(evutil_socket_t fd, SSL* ssl, ioa_network_buffer_handle nbh, int ve
 int set_raw_socket_ttl_options(evutil_socket_t fd, int family);
 int set_raw_socket_tos_options(evutil_socket_t fd, int family);
 
-int set_socket_options_fd(evutil_socket_t fd, int tcp, int family);
+int set_socket_options_fd(evutil_socket_t fd, SOCKET_TYPE st, int family);
 int set_socket_options(ioa_socket_handle s);
 
 int send_session_cancellation_to_relay(turnsession_id sid);
@@ -303,6 +308,8 @@ int send_data_from_ioa_socket_tcp(ioa_socket_handle s, const void *data, size_t
 int send_str_from_ioa_socket_tcp(ioa_socket_handle s, const void *data);
 int send_ulong_from_ioa_socket_tcp(ioa_socket_handle s, size_t data);
 
+int ioa_socket_check_bandwidth(ioa_socket_handle s, ioa_network_buffer_handle nbh, int read);
+
 ///////////////////////// SUPER MEMORY ////////
 
 #define allocate_super_memory_engine(e,size) allocate_super_memory_engine_func(e, size, __FILE__, __FUNCTION__, __LINE__)
